@@ -251,6 +251,15 @@ DXF::header(const char *, const char *, time_t,
 	       "40\n2.5\n"
 	       "49\n1.25\n"
 	       "49\n-1.25\n"
+	       "0\nLTYPE\n" /* define DOT line type */
+	       "2\nDOT\n"
+	       "70\n64\n"
+	       "3\nDotted\n"
+	       "72\n65\n"
+	       "73\n2\n"
+	       "40\n1\n"
+	       "49\n0\n"
+	       "49\n1\n"
 	       "0\nENDTAB\n");
    fprintf(fh, "0\nTABLE\n"
 	       "2\nLAYER\n");
@@ -285,6 +294,11 @@ DXF::header(const char *, const char *, time_t,
    fprintf(fh, "70\n64\n"); /* shows layer is referenced by entities */
    fprintf(fh, "62\n7\n"); /* color */
    fprintf(fh, "6\nCONTINUOUS\n"); /* linetype */
+   /* Next Layer: Splays */
+   fprintf(fh, "0\nLAYER\n2\nSplays\n");
+   fprintf(fh, "70\n64\n"); /* shows layer is referenced by entities */
+   fprintf(fh, "62\n5\n"); /* color */
+   fprintf(fh, "6\nDOT\n"); /* linetype;  */
    if (grid > 0) {
       /* Next Layer: Grid */
       fprintf(fh, "0\nLAYER\n2\nGrid\n");
@@ -333,9 +347,16 @@ void
 DXF::line(const img_point *p1, const img_point *p, unsigned flags, bool fPendingMove)
 {
    bool fSurface = (flags & SURF);
+   bool fSplay = (flags & SPLAYS);
    (void)fPendingMove; /* unused */
    fprintf(fh, "0\nLINE\n");
-   fprintf(fh, fSurface ? "8\nSurface\n" : "8\nCentreLine\n"); /* Layer */
+   if (fSurface) { /* select layer */
+      fprintf(fh, "8\nSurface\n" );
+   } else if (fSplay) {
+      fprintf(fh, "8\nSplays\n");
+   } else {
+      fprintf(fh, "8\nCentreLine\n");
+   }
    fprintf(fh, "10\n%6.2f\n", p1->x);
    fprintf(fh, "20\n%6.2f\n", p1->y);
    fprintf(fh, "30\n%6.2f\n", p1->z);
